SYBIL_SETTINGS: Set and Get sybil Parameters

View source: R/settings.R

SYBIL_SETTINGSR Documentation

Set and Get sybil Parameters

Description

Manage a set of default parameter settings for sybil.

Usage

  SYBIL_SETTINGS(parm, value, ...)

Arguments

parm

A character string giving the name of the parameter to set.

value

The corresponding value.

...

Further arguments passed to checkDefaultMethod. Only used if parameters "SOLVER" or "METHOD" are set.

Details

Typical usages are

    SYBIL_SETTINGS(parm, value)
    SYBIL_SETTINGS(parm)
    SYBIL_SETTINGS()
  

Possible parameters are:

"SOLVER"

The default solver for lp problems. Possible values are depend on your installed API package.

glpkAPI:

"glpkAPI",

cplexAPI:

"cplexAPI",

clpAPI:

"clpAPI",

lpSolveAPI:

"lpSolveAPI".

Default: "glpkAPI".

"METHOD"

The default method to solve lp problems. Possible values are

glpkAPI:

"simplex", "interior", "exact" or mip.

cplexAPI:

"lpopt", "primopt" "dualopt", "baropt", "hybbaropt", "hybnetopt", "siftopt", mipopt or qpopt.

clpAPI:

"general_solve", "inidual" "iniprimal", "inibarrier", "inibarriernoc", "idiot", "dual" or "primal".

lpSolveAPI:

"lp_solve".

Default: "simplex".
If the parameter "SOLVER" is changed, the corrsponding default "METHOD" is the first one mentioned, e.g. for "cplexAPI", it will be "lpopt". This change is done automatically when changing the solver. It is not possible, to set a not existing "METHOD" for a particular "SOLVER", the corresponding default value will be used in such a case.

"MAXIMUM"

Absolute maximum value.
Default: 1000.

"MODELORG_VERSION"

Currtent version of modelorg-Class.
Value: "2.0".
This value must not be changed.

"ALGORITHM"

Algorithm to use in order to analyze metabolic networks. Possible values are:

"fba"

flux-balance analysis,

"fv"

flux-variance analysis,

"mtf"

minimize total flux,

"moma"

minimization of metabolic adjustment (MOMA),

"lmoma"

linear version of MOMA,

"room"

regulatory on/off minimization (ROOM).

Default: "fba".

"OPT_DIRECTION"

Direction of optimization. Can be "max" or "min".
Default: "max".

"USE_NAMES"

A logical value indicating if reaction id's and metabolite id's (or other names) should be used as names for variables and constraints in objects of class sysBiolAlg.
Default: FALSE.

"PATH_TO_MODEL"

Path to a directory to read or write files.
Default: ".".

"SOLVER_CTRL_PARM"

A data.frame giving parameters to the optimizer software (e.g. GLPK).
Default: as.data.frame(NA).

"TOLERANCE"

Tolerance value.
Default: 1E-6.

Value

If successful, a set of parameters to sybil will be returned.

Author(s)

Gabriel Gelius-Dietrich <geliudie@uni-duesseldorf.de>

Maintainer: Mayo Roettger <mayo.roettger@hhu.de>

See Also

checkDefaultMethod

Examples

  ## show all current parameters
  SYBIL_SETTINGS()
  
  ## show current setting for "SOLVER"
  SYBIL_SETTINGS("SOLVER")

  ## change current solver to glpkAPI
  SYBIL_SETTINGS("SOLVER", "glpkAPI")
## Not run: 
  ## this needs cplexAPI installed
  ## change current solver to cplexAPI
  SYBIL_SETTINGS("SOLVER", "cplexAPI")

## End(Not run)

SysBioChalmers/sybil documentation built on Aug. 24, 2023, 1:08 p.m.