applyChanges to apply changes in objects of class
sysBiolAlg . Changes can be coefficients of the objective
function, variable bounds or the optimization direction.## S3 method for class 'sysBiolAlg':
applyChanges(object, del, obj, ld,
react = NULL,
lb = NULL,
ub = NULL,
obj_coef = NULL,
lpdir = NULL)## S3 method for class 'sysBiolAlg_room':
applyChanges(object, del, obj, ld,
react = NULL,
lb = NULL,
ub = NULL,
obj_coef = NULL,
lpdir = NULL)
sysBiolAlg .NULL.react, containing the new lower
variable bounds.
Default: NULL.react, containing the new upper
variable bounds.
Default: NULL.react, containing the new
objective coefficients.
Default: NULL.NULL.resetChanges:react containing the original
variable lower bounds.react containing the original
variable upper bounds.react containing the original
objective coefficients.react containing row indices
of the stoichiometric matrix required to apply changes in variable bounds
when algorithm "room" is used.
(only used by the sysBiolAlg_room method).react containing column
indices of the stoichiometric matrix required to apply changes in variable
bounds when algorithm "room" is used.
(only used by the sysBiolAlg_room method).sysBiolAlg and resetChanges