Learn R Programming

sybil (version 1.1.1)

checkOptSol-methods: Summarized Information About an Object of Class Optsol

Description

The function checkOptSol evaluates the results of the solution of optimizations; the returned objects e.g. from optimizeProb.

Usage

## S3 method for class 'optsol':
checkOptSol(opt, onlywarn = FALSE)

Arguments

opt
An object of class optsol.
onlywarn
A single Boolean value. If set to TRUE, the method will check, if all optimizations ended successfully. Default: FALSE.

Value

  • TRUE or FALSE if onlywarn is set to TRUE, otherwisw an object of class checksol.

encoding

utf8

Details

The function checkOptSol is used by functions performing a linear optimization (e.g. optimizeProb). In that case, the argument onlywarn is set to TRUE. If the optimization ends unsuccesfull, a warning will be produced.

It is also possible to use the function directly, with onlywarn set to FALSE (the default). In that case, an object of class checksol will be retuned. This object contains a summary with the exit status of the optimization.

See Also

checksol, optimizeProb and oneGeneDel

Examples

Run this code
data(Ec_core)
  Ec_f <- optimizeProb(Ec_core, retOptSol = TRUE)
  Ec_check <- checkOptSol(Ec_f)

Run the code above in your browser using DataLab