| checksol-class | R Documentation |
Structure of the class "checksol". Objects of that class are
returned by the function checkOptSol.
Objects can be created by calls of the form new("checksol").
exit_code:Object of class "integer"
containing the exit code of the lp solver.
exit_num:Object of class "integer"
containing the number of appearance of a specific exit code.
exit_meaning:Object of class "character"
containing the meaning of the exit code.
num_of_prob:Object of class "integer"
indicating the number of optimization problems.
status_code:Object of class "integer"
containing the solution status of the lp problem.
status_num:Object of class "integer"
containing the number of appearance of a specific solution status.
status_meaning:Object of class "character"
containing the meaning of the solution status.
exit_code<-:signature(object = "checksol"):
sets the exit_code slot.
exit_code:signature(object = "checksol"):
gets the exit_code slot.
exit_meaning<-:signature(object = "checksol"):
sets the exit_meaning slot.
exit_meaning:signature(object = "checksol"):
gets the exit_meaning slot.
exit_num<-:signature(object = "checksol"):
sets the exit_num slot.
exit_num:signature(object = "checksol"):
gets the exit_num slot.
num_of_prob<-:signature(object = "optsol"):
sets the num_of_prob slot.
num_of_prob:signature(object = "optsol"):
gets the num_of_prob slot.
show:signature(object = "checksol"):
prints some details specific to the instance of class checksol.
status_code<-:signature(object = "checksol"):
sets the status_code slot.
status_code:signature(object = "checksol"):
gets the status_code slot.
status_meaning<-:signature(object = "checksol"):
sets the status_meaning slot.
status_meaning:signature(object = "checksol"):
gets the status_meaning slot.
status_num<-:signature(object = "checksol"):
sets the status_num slot.
status_num:signature(object = "checksol"):
gets the status_num slot.
Gabriel Gelius-Dietrich <geliudie@uni-duesseldorf.de>
Maintainer: Mayo Roettger <mayo.roettger@hhu.de>
checkOptSol
showClass("checksol")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.