doubleFluxDel(model, react1, react2, lb = NULL, ub = NULL,
allComb = FALSE, exex = FALSE, checkOptSolObj = FALSE, ...)modelorg .reactId or character or integer
containing reaction id's to constrain to zero.
Default: react_id(model).reactId or character or integer
containing reaction id's to constrain to zero.
Default: react_id(model).react1 and react2.
If set to NULL, all reactions will be constrained to zero.
Default: NULreact1 and react2.
If set to NULL, all reactions will be constrained to zero.
Default: NULTRUE, every possible pairwise
combination of reactions given in arguments react1 and react2
will be constrained to zero flux. If set to FALSE, arguments
TRUE, exchange reactions will be
excluded from the analysis. They are identified by the function
findExchReact.
Default: FALSE.TRUE, a warning will be generated,
if not all optimizations ended successful.
Default: FALSE.optimizer. Important ones are
algorithm in order to set the algorithm to use or solverParm
in order to set parameter values for the optimizatoptsol_fluxdel .doubleFluxDel studies the effect of double flux deletions
on the phenotype of the metabolic network. The function performs $n$
optimizations with $n$ being either the number of reaction id's in
argument react1 times the number of reaction id's in argument
react2, if argument allComb is set to TRUE, or the length
of one of these vectors if argument allComb is set to FALSE.
Each optimization corresponds to the simultaneous deletion of two fluxes.modelorg, optsol ,
optsol_fluxdel ,
checkOptSol, optimizer and
SYBIL_SETTINGS.data(Ec_core)
Ec_dfd <- doubleFluxDel(Ec_core)Run the code above in your browser using DataLab