Learn R Programming

sybil (version 1.1.1)

editEnvir: Environment Editor for Metabolic Networks

Description

Environment editor for metabolic networks. The function editEnvir opens the exchange reactions of a metabolic network in R's data editor. Changes in upper and lower bounds will be set in the given model.

Usage

editEnvir(model, newKey = FALSE, ...)

Arguments

model
An object of class modelorg.
newKey
If set to TRUE, a new model key will be generated.
...
Further arguments passed to edit.

Value

  • An object of class modelorg.

See Also

checkReactId

Examples

Run this code
## change environment of E.coli core model:
  data(Ec_core)
  mod <- editEnvir(Ec_core)

Run the code above in your browser using DataLab