| fluxDistribution-class | R Documentation |
"fluxDistribution"Structure of the class "fluxDistribution". Objects of that class are
used by class "optsol" in order to store flux
distributions. Flux distributions are stored column by column; each flux
corresponds to one row and the optimizations correspond to the columns.
Objects can be created by calls of the form
test <- fluxDistribution(fluxes, nrow = 1, ncol = 1.
If argument fluxes is of class Matrix or matrix,
num_of_fluxes is set to ncol(fluxes) * nrow(fluxes).
If argument fluxes is a vector, a matrix will be generated according
to nrow and ncol.
fluxes:Object of class "Matrix" containing fluxdistributions column by
column.
num_of_fluxes:Object of class "integer" containing the number of elements in
fluxes.
[signature(x = "fluxDistribution"): subsetting operator for the
matrix of flux distributions.
fluxessignature(object = "fluxDistribution"): gets the fluxes
slot.
fluxes<-signature(object = "fluxDistribution"): sets the fluxes
slot.
num_of_fluxessignature(object = "fluxDistribution"): gets the
num_of_fluxes slot.
nnzerosignature(object = "fluxDistribution"): gets the number of
non-zero elements in slot fluxes.
nvarsignature(object = "fluxDistribution"): gets the number of
fluxes in the fluxdistribution in slot fluxes (the number of rows
of slot fluxes).
plotsignature(x = "fluxDistribution", y = "missing"): heatmap like
plotting method for fluxdistributions. Not finished yet.
Gabriel Gelius-Dietrich <geliudie@uni-duesseldorf.de>
Maintainer: Mayo Roettger <mayo.roettger@hhu.de>
showClass("fluxDistribution")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.