| getsybilenv | R Documentation |
Prints current settings in the sybil environment.
getsybilenv(part)
part |
A character vector containing names of elements in the sybil environment. Possible values are:
|
Typical usages are
getsybilenv(part)
getsybilenv()
If argument part is not given, all elements described above will be
printed.
Returns NULL invisibly.
Gabriel Gelius-Dietrich <geliudie@uni-duesseldorf.de>
Maintainer: Mayo Roettger <mayo.roettger@hhu.de>
addSolver, checkDefaultMethod
and SYBIL_SETTINGS.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.