Learn R Programming

sybil (version 1.1.1)

netFlux-class: Class "netFlux"

Description

Class "netFlux" groups exchange reaction rates according to their sign in uptake, excretion and unused reactions.

Arguments

encoding

utf8

Objects from the Class

Objects can be created by calls of the form getNetFlux(rates, tol), with argument rates being a named numeric vector containing reaction rates of exchange fluxes and corresponding reaction id's. Argument rates can be obtained by a call to optimizeProb. The second argument tol is a tolerance value (default: SYBIL_SETTINGS("TOLERANCE")). Reaction rates less than tol * -1 are uptake reactions, reaction rates greater than tol are excretion reactions and all others (abs(rates) < tol) are unused reactions.

See Also

optimizeProb, getFluxDist

Examples

Run this code
data(Ec_core)
  # retrieve all exchange reactions
  ex  <- findExchReact(Ec_core)
  # perform flux balance analysis
  opt <- optimizeProb(Ec_core, algorithm = "fba")
  # get flux distribution of all exchange reactions
  fd  <- getFluxDist(opt, ex)
  # group exchange reactions
  getNetFlux(fd)

Run the code above in your browser using DataLab