Learn R Programming

sybil (version 1.1.1)

oneGeneDel: Single Gene Deletion Experiment

Description

Predict the metabolic phenotype of single-gene knock out mutants.

Usage

oneGeneDel(model, geneList,
             lb = rep(0, length(geneList)),
             ub = rep(0, length(geneList)),
             checkOptSolObj = FALSE, ...)

Arguments

model
An object of class modelorg.
geneList
A character vector containing the set of genes to be deleted one by one. Default: allGenes(model).
lb
A numeric vector of the same length as geneList containing the lower bounds for the reaction rates of reactions (variables) affected by the genes given in argument geneList. Default: 0 for all genes in
ub
A numeric vector of the same length as geneList containing the upper bounds for the reaction rates of reactions (variables) affected by the genes given in argument geneList. Default: 0 for all genes in
checkOptSolObj
A single logical value. If set to TRUE, a warning will be generated, if not all optimizations ended successful. Default: FALSE.
...
Further arguments passed to optimizer. Important ones are algorithm in order to set the algorithm to use or solverParm in order to set parameter values for the optimizat

Value

  • An object of class optsol_genedel.

encoding

utf8

Details

The function oneGeneDel studies the effect of genetic perturbations by single gene deletions on the phenotype of the metabolic network. The function performs $n$ optimizations with $n$ being the length of the character vector in argument geneList. For each gene deletion $j$ the set of fluxes effected by the deletion of gene given in geneList[j] is constrained to zero flux. If the deletion of a certain gene has an effect, is tested with the function geneDel. Each optimization corresponds to the deletion of one gene.

See Also

modelorg, optsol, optsol_genedel, checkOptSol, optimizer and SYBIL_SETTINGS.

Examples

Run this code
# load example data set
  data(Ec_core)
  
  # compute phenotypes of genetic perturbations via
  # FBA (default)
  Ec_ogd <- oneGeneDel(Ec_core)
  
  # or MOMA (linearized version)
  Ec_ogd <- oneGeneDel(Ec_core, algorithm = "lmoma")

Run the code above in your browser using DataLab