Learn R Programming

sybil (version 1.1.1)

printMetabolite-methods: Print Rows of the Stoichiometric Matrix

Description

Print the rows of the stoichiometric matrix or an FBA model in CPLEX LP file format.

Usage

## S3 method for class 'modelorg':
printMetabolite(object, met, FBAlp = FALSE, printOut = TRUE, ...)

Arguments

object
An object of class modelorg.
met
A numeric or character vector containing the metabolite id's of metabolites to print out. If missing, all metabolites given in the model are used.
FBAlp
A single logical value. If set to TRUE, the output will be in CPLEX LP file format, including the objective function given in the model and reaction bounds. Additionally, if set to TRUE, argument met will
printOut
A single Boolean value. If set to TRUE, the desired reactions will be printed via the cat function. Default: TRUE.
...
Further arguments passed to cat, e.g. argument file.

Value

  • The modelorg method returns a character vector of length equal to the number of metabolites given in argument met, invisibly. Each string represents the reaction participation of one particular metabolite.

encoding

utf8

Details

Metabolite id's not beginning with a letter will be prefixed by the letter "n" and square brackets will be replaced by round brackets.

See Also

Class modelorg