Learn R Programming

sybil (version 1.1.1)

printReaction-methods: Print Columns of the Stoichiometric Matrix

Description

Print the columns of the stoichiometric matrix.

Usage

## S3 method for class 'modelorg,ANY':
printReaction(object, react, printOut = TRUE, ...)
## S3 method for class 'summaryOptsol,modelorg':
printReaction(object, mod, j, ...)

Arguments

object
An object of class modelorg or of class summaryOptsol.
mod
An object of class modelorg.
react
A numeric of character vector or an object of class reactId containing the reaction id's of reactions to print out.
j
A numeric of character vector indicating the simulations to consider, see Details.
printOut
A single Boolean value. If set to TRUE, the desired reactions will be printed via the cat function. Default: TRUE.
...
Further arguments passed to cat, e.g. argument file.

Value

  • The modelorg method returns invisibly a character vector of length equal to the number of reactions given in argument react. Each string consists of two tab-delimited values: first, the reaction id, second, the reaction equation. The summaryOptsol returns invisibly a list of length equal to the number of elements in argument j. Each list element is of the same type as the return value of the modelorg method.

encoding

utf8

Details

The output of the modelorg method is compatible to the file format produced by modelorg2tsv. Two columns are used: "abbreviation" containing the reaction id's and "equation" containing the reaction equation. The summaryOptsol method prints the limiting reactions generated in simulations and stored in objects of class summaryOptsol. Slot react_id of class summaryOptsol contains a list of reaction id's: list element j gives the reaction id's limiting simulation number j.

See Also

Class modelorg and class summaryOptsol.