Learn R Programming

sybil (version 1.1.1)

readProb-methods: Read Problem Object From File

Description

Read problem object from file.

Usage

## S3 method for class 'optObj_clpAPI,character':
readProb(lp, fname, ff = "mps", ...)

## S3 method for class 'optObj_cplexAPI,character': readProb(lp, fname, ff = "lp")

## S3 method for class 'optObj_glpkAPI,character': readProb(lp, fname, ff = "lp", ...)

## S3 method for class 'optObj_lpSolveAPI,character': readProb(lp, fname, ff = "lp", ...)

Arguments

lp
An object extending class optObj.
fname
A single character string giving the file name to read from.
ff
A single character string giving the file format to use, see Details. Default: "lp".
...
Further arguments passed to the corresponding API routine.

encoding

utf8

Details

Argument "ff" in conjunction with clpAPI can be mps for MPS file format or "clp" for COIN-OR Clp file mormat. Valid values for cplexAPI and lpSolveAPI are available in their documentations. For glpkAPI, argument "ff" can be "lp" for LP file format, "mps" for MPS file format or "glpk" for GLPK file format.

See Also

Superclass optObj and constructor function optObj.