View source: R/summaryOptsolClass.R
| summaryOptsol | R Documentation |
Generates a quick overview of results of simulations stored in objects
of class optsol.
summaryOptsol(opt, mod, perc = 1, tol = SYBIL_SETTINGS("TOLERANCE"))
opt |
An object of class |
mod |
An object of class |
perc |
A single numeric value in between zero and one indicating how close a flux
value has to reach a flux boundary in order to be called “limiting”,
see Details below. |
tol |
A tolerance value, see Details below. |
The function summaryOptsol generates a summary of the simulations
resulting in the object given in argument opt. Both model id's, of
the optsol object and of the
modelorg object must be identical. The resulting object
of class summaryOptsol contains information about the
number of zeros and non-zeros in the flux distribution, the substrates and
products and about the limiting reactions.
A reaction i is called “limiting”, if its flux value v_i
is non-zero: |v_i| > \mathit{tol} and if its flux value
hits the flux boundaries:
v_i \leq v_{i,\textrm{min}} \cdot \mathit{perc} \lor
v_i \geq v_{i,\textrm{max}} \cdot \mathit{perc}.
An object of class summaryOptsol if a flux distribution
exists in argument opt, otherwise a summary of the
objective values (mod_obj) is returned.
Gabriel Gelius-Dietrich <geliudie@uni-duesseldorf.de>
Maintainer: Mayo Roettger <mayo.roettger@hhu.de>
Class optsol, class modelorg and
class summaryOptsol.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.