Learn R Programming

sybil (version 1.1.1)

summaryOptsol-class: Class "summaryOptsol"

Description

Class summaryOptsol stores a summary of instances of class optsol.

Arguments

encoding

utf8

Objects from the Class

Objects can be created by calls of the form summaryOptsol(opt, mod).

See Also

Constructor function summaryOptsol, class optsol and class modelorg.

Examples

Run this code
showClass("summaryOptsol")

Run the code above in your browser using DataLab