## S3 method for class 'modelorg':
printMetabolite(object, met, FBAlp = FALSE, printOut = TRUE, ...)modelorg .TRUE, the output will be in
CPLEX LP file format, including the objective function given in the model
and reaction bounds. Additionally, if set to TRUE, argument
met willTRUE, the desired reactions will
be printed via the cat function.
Default: TRUE.cat, e.g. argument file.modelorg method returns a character vector of length
equal to the number of metabolites given in argument met, invisibly.
Each string represents the reaction participation of one particular
metabolite."n" and square brackets will be replaced by round brackets.modelorg