## S3 method for class 'modelorg,ANY':
printReaction(object, react, printOut = TRUE, ...)
## S3 method for class 'summaryOptsol,modelorg':
printReaction(object, mod, j, ...)modelorg or of class
summaryOptsol .modelorg .reactId containing the reaction id's of reactions
to print out.TRUE, the desired reactions will
be printed via the cat function.
Default: TRUE.cat, e.g. argument file.modelorg method returns invisibly a character vector
of length equal to the number of reactions given in argument react.
Each string consists of two tab-delimited values: first, the reaction id,
second, the reaction equation.
The summaryOptsol returns invisibly a list of length
equal to the number of elements in argument j. Each list element is
of the same type as the return value of the modelorg
method.modelorg method is compatible to the
file format produced by modelorg2tsv. Two columns are used:
"abbreviation" containing the reaction id's and "equation"
containing the reaction equation.
The summaryOptsol method prints the limiting reactions
generated in simulations and stored in objects of class
summaryOptsol . Slot react_id of class
summaryOptsol contains a list of reaction id's: list
element j gives the reaction id's limiting simulation number j.modelorg and
class summaryOptsol .