shrinkMatrix-methods: Get a Subset of Matrix Like Objects
Description
Generate subsets of matrix-like objects.
Usage
## S3 method for class 'modelorg':
shrinkMatrix(X, i = NULL, j = NULL,
tol = SYBIL_SETTINGS("TOLERANCE"))
Arguments
X
An object treated to be matrix-like.
i
A numeric or character vector containing row indices of the matrix
given in argument X. For the modelorg method,
this can be an object of class reactId.
D
j
A numeric or character vector containing column indices of the
matrix given in argument X. For the modelorg
method, this can be an object of class reactId_Exch
tol
A tolerance value. An element $X_{ij}$ of the matrix given in
argument X is considered to be zero, if
$|X_{ij}| > \mathit{tol}$ is true.
Default: SYBIL_SETTINGS("TOLERANCE").
Value
The modelorg method will return an object of class
Matrix, with columns named by their reaction id's and
rows named by their metabolite id's.